@@ -49,7 +49,7 @@ public:
      * @param[in] baseClustering optional; the algorithm will start from the given clustering.
      * @param[in] theta updateThreshold: number of nodes that have to be changed in each iteration so that a new iteration starts.
      */
-    PLP(const Graph& G, const Partition baseClustering, count theta = none);
+    PLP(const Graph &G, Partition baseClustering, count theta = none);
 
     /**
      * Run the label propagation clustering algorithm.
