@@ -130,11 +130,11 @@ namespace NetworKit {
             *v = {source, availableSources[source][i]};
             std::vector<bool> visited(G->upperNodeIdBound(), false);
             visited[source] = true;
-            stack.push_back(std::make_pair(*v, visited));
+            stack.emplace_back(*v, visited);
 
             std::vector<std::vector<node>> currPaths;
 
-            while (stack.size() > 0) {
+            while (!stack.empty()) {
 
                 node curr = stack.back().first.back();
 
@@ -157,7 +157,7 @@ namespace NetworKit {
                 currPair->second[curr] = true;
                 bool toEnqueue = false;
 
-                if (availableSources[curr].size() > 0) {
+                if (!availableSources[curr].empty()) {
                     node s = availableSources[curr][0];
                     if (!currPair->second[s]) {
                         currPair->first.push_back(s);
@@ -181,7 +181,7 @@ namespace NetworKit {
                             toEnqueue = false;
                         }
                         else {
-                            stack.push_back(std::pair<std::vector<node>, std::vector<bool>> (*currPair));
+                            stack.emplace_back(*currPair);
                             std::pair<std::vector<node>, std::vector<bool>>* newPair = &stack.back();
                             newPair->first[newPair->first.size() - 1] = s;
                             ++step;
