@@ -18,17 +18,17 @@ color(G.upperNodeIdBound(), WHITE) {
 }
 
 void DynBFS::run() {
-    BFS bfs(G, source, true);
+    BFS bfs(*G, source, true);
     bfs.run();
     distances = bfs.getDistances();
-    npaths.reserve(G.upperNodeIdBound());
-    G.forNodes([&](node u) {npaths.push_back(bfs.numberOfPaths(u)); });
+    npaths.reserve(G->upperNodeIdBound());
+    G->forNodes([&](node u) {npaths.push_back(bfs.numberOfPaths(u)); });
     if (storePreds) {
-        previous.resize(G.upperNodeIdBound());
-        G.forNodes([&](node u) { previous[u] = bfs.getPredecessors(u); });
+        previous.resize(G->upperNodeIdBound());
+        G->forNodes([&](node u) { previous[u] = bfs.getPredecessors(u); });
     }
     maxDistance = 0;
-    G.forNodes([&](node v){
+    G->forNodes([&](node v){
         if (distances[v] > maxDistance)
             maxDistance = distances[v];
     });
@@ -76,7 +76,7 @@ void DynBFS::updateBatch(const std::vector<GraphEvent>& batch) {
                 previous[w].clear();
             }
             npaths[w] = 0;
-            G.forInNeighborsOf(w, [&](node w, node z) {
+            G->forInNeighborsOf(w, [&](node w, node z) {
                 //z is a predecessor for w
                 if (distances[w] == distances[z]+1) {
                     if (storePreds) {
