@@ -972,7 +972,7 @@ std::vector<std::pair<node, node>> Graph::edges() const {
     WARN("Graph::edges is deprecated and will not be supported in future releases.");
     std::vector<std::pair<node, node>> edges;
     edges.reserve(numberOfEdges());
-    this->forEdges([&](node u, node v) { edges.push_back(std::pair<node, node>(u, v)); });
+    this->forEdges([&](node u, node v) { edges.emplace_back(u, v); });
     return edges;
 }
 
