@@ -174,7 +174,7 @@ std::vector<std::pair<node, node>> randomEdges(const Graph &G, count nr) {
                 v = randomNeighbor(G, u);
             } while (u > v);
         }
-        edges.push_back({u, v});
+        edges.emplace_back(u, v);
     }
 
     return edges;
@@ -422,7 +422,7 @@ std::vector<node> invertContinuousNodeIds(const std::unordered_map<node, node> &
     // store upper node id bound
     invertedIdMap[G.numberOfNodes()] = G.upperNodeIdBound();
     // inverted node mapping
-    for (const auto x : nodeIdMap) {
+    for (const auto &x : nodeIdMap) {
         invertedIdMap[x.second] = x.first;
     }
     return invertedIdMap;
