@@ -9,33 +9,33 @@
 
 namespace NetworKit {
 
-MultiscaleScore::MultiscaleScore(const Graph& G, const std::vector<double>& attribute) : EdgeScore<double>(G), attribute(attribute) {}
+MultiscaleScore::MultiscaleScore(const Graph& G, const std::vector<double>& attribute) : EdgeScore<double>(G), attribute(&attribute) {}
 
 void MultiscaleScore::run() {
-    if (!G.hasEdgeIds()) {
+    if (!G->hasEdgeIds()) {
         throw std::runtime_error("edges have not been indexed - call indexEdges first");
     }
 
     //The following vector is used for the _local_ normalization of edgeweights.
     //We use a global vector for performance reasons.
-    std::vector<edgeweight> normalizedWeights(G.upperNodeIdBound());
+    std::vector<edgeweight> normalizedWeights(G->upperNodeIdBound());
 
-    std::vector<double> multiscaleAttribute(G.upperEdgeIdBound(), 0.0);
+    std::vector<double> multiscaleAttribute(G->upperEdgeIdBound(), 0.0);
 
-    G.forNodes([&](node u) {
-        count k = G.degree(u);
+    G->forNodes([&](node u) {
+        count k = G->degree(u);
 
         //Normalize edgeweights of N(u)
         edgeweight sum = 0.0;
-        G.forNeighborsOf(u, [&](node, node, edgeid eid) {
-            sum += attribute[eid];
+        G->forNeighborsOf(u, [&](node, node, edgeid eid) {
+            sum += (*attribute)[eid];
         });
-        G.forNeighborsOf(u, [&](node, node v, edgeid eid) {
-            normalizedWeights[v] = attribute[eid] / sum;
+        G->forNeighborsOf(u, [&](node, node v, edgeid eid) {
+            normalizedWeights[v] = (*attribute)[eid] / sum;
         });
 
         //Filter edges by probability
-        G.forNeighborsOf(u, [&](node, node v, edgeid eid) {
+        G->forNeighborsOf(u, [&](node, node v, edgeid eid) {
             //In case d(u) == 1 and d(v) > 1: ignore u
             //if (k > 1 || G.degree(v) == 1) {
                 edgeweight p = normalizedWeights[v];
