@@ -1,6 +1,7 @@
 # extension imports
-from _NetworKit import Graph, GraphEvent, DGSStreamParser, GraphUpdater, APSP, GraphDifference
-
+from .graph import Graph
+from .dynamics import GraphEvent, DGSStreamParser, GraphUpdater, GraphDifference
+from .distance import APSP
 
 def graphFromStream(stream, weighted, directed):
 	""" Convenience function for creating a new graph from a stream of graph events
